#include <default.c>
#include <acknex.h>

var starting = 0;

var score_p1 = 0;
var score_p2 = 0;
var score_max = 5;

FONT *score_font = "Verdana#18";

VECTOR *ballspeed = { x=10; y=10; z=0; }
var balldamping = 0.2;

TEXT *start =
{
	pos_x = 0;
	pos_y = 0;
	
	red = 255;
	green = 255;
	blue = 255;
	alpha = 100;
	
	font = "Verdana#120b";
	string ("3");
	
	layer = 10;
	flags = CENTER_X | CENTER_Y;
}

PANEL *score =
{
	pos_x = 0;
	pos_y = 0;
	
	red = 255;
	green = 255;
	blue = 255;
	alpha = 100;
	
	digits (5, 5, "Score", "Verdana#20b", 1, 0);
	digits (6, 25, "%.0f", score_font, 1, score_p1);
	digits (16, 25, "  -  %.0f", score_font, 1, score_p2);
	
	layer = 2;
	flags = SHOW;	
}

PANEL *player1 =
{
	pos_x = 0;
	pos_y = 0;
	
	size_x = 150;
	size_y = 50;
	
	red = 0;
	green = 0;
	blue = 255;
	alpha = 100;
	
	layer = 1;
	flags = SHOW | LIGHT;
}

PANEL *player2 =
{
	pos_x = 0;
	pos_y = 0;
	
	size_x = 150;
	size_y = 50;
	
	red = 255;
	green = 0;
	blue = 0;
	alpha = 100;
	
	layer = 1;
	flags = SHOW | LIGHT;
}

PANEL *ball =
{
	pos_x = 0;
	pos_y = 0;
	
	size_x = 20;
	size_y = 20;
	
	red = 255;
	green = 255;
	blue = 255;
	alpha = 100;
	
	layer = 2;
	flags = SHOW | LIGHT;
}

function control(PANEL *p, var key_left, var key_right)
{
	if (key_left)
	{
		p.pos_x -= 1;
	}
	else if (key_right)
	{
		p.pos_x += 1;
	}
	
	if (p.pos_x + p.size_x >= screen_size.x)
	{
		p.pos_x = screen_size.x - p.size_x;
	}
	else if (p.pos_x <= 0)
	{
		p.pos_x = 0;
	}
}

function restart()
{	
	starting = 1;
	
	player1.pos_x = (screen_size.x - player1.size_x) / 2;
	player1.pos_y = screen_size.y - player1.size_y - 30;
	
	player2.pos_x = (screen_size.x - player2.size_x) / 2;
	player2.pos_y = 30;
	
	ball.pos_x = (screen_size.x - ball.size_x) / 2;
	ball.pos_y = (screen_size.y - ball.size_y) / 2;
	
	vec_set(ballspeed, vector(10, 10, 0));
	
	wait(-2);
	
	start.pos_x = screen_size.x / 2;
	start.pos_y = screen_size.y / 2;	
	str_cpy((start.pstring)[0], " ");
	set(start, SHOW);	
	str_cpy((start.pstring)[0], "3");
	wait(-1);
	str_cpy((start.pstring)[0], "2");
	wait(-1);	
	str_cpy((start.pstring)[0], "1");
	wait(-1);
	str_cpy((start.pstring)[0], "START");
	wait(-1);
	reset(start, SHOW);
	
	starting = 0;
}

function move_ball()
{	
	ball.pos_x += ballspeed.x * time_step;
	ball.pos_y += ballspeed.y * time_step;
	
	ballspeed.x -= balldamping * time_step;
	ballspeed.y -= balldamping * time_step;
	
	if (ball.pos_y + ball.size_y <= 0)
	{
		score_p1 += 1;
		restart();
	}
	else if (ball.pos_y + ball.size_y >= screen_size.y)
	{
		score_p2 += 1;
		restart();
	}
	
	if ((ball.pos_x >= player1.pos_x && ball.pos_x + ball.size_x <= player1.pos_x + player1.size_x)
		&& ball.pos_y + ball.size_y >= player1.pos_y)
	{
		ball.pos_y = player1.pos_y - ball.size_y - 1;
		ballspeed.y *= -1.1;
	}
	else if ((ball.pos_x >= player2.pos_x && ball.pos_x + ball.size_x <= player2.pos_x + player2.size_x)
		&& ball.pos_y <= player2.pos_y + player2.size_y)
	{
		ball.pos_y = player2.pos_y + player2.size_y + 1;
		ballspeed.y *= -1.1;
	}
	
	if (ball.pos_x + ball.size_x >= screen_size.x || ball.pos_x <= 0)
	{
		ballspeed.x *= -1;
	}
}

function winner()
{
	var have_winner = 0;
	
	if (score_p1 >= score_max)
	{
		have_winner = 1;	
	}
	else if (score_p2 >= score_max)
	{
		have_winner = 2;	
	}
	
	if (have_winner)
	{
		score_p1 = 0;
		score_p2 = 0;
		
		if (have_winner == 1)
			str_cpy((start.pstring)[0], "PLAYER1 HAS WON");
		else
			str_cpy((start.pstring)[0], "PLAYER2 HAS WON");
		set(start, SHOW);	
		wait(-5);
		reset(start, SHOW);
		
		restart();
	}
}

function main()
{
	video_mode = 8;
	video_screen = 2;
	
	random_seed(0);
	
	wait(1);
	
	restart();
	
	while (1)
	{
		while (starting)
		{
			wait(1);
		}
		
		control(player1, key_cul, key_cur);
		control(player2, key_a, key_d);
		
		move_ball();
		
		winner();
		
		wait(1);
	}
}